mysql.stmt.stmt

Package mysql :: Package stmt :: Module stmt |
[hide private]
[frames] | no frames]

# Module stmt

MySQL Statement object.

The Statement object represents a parsed SQL statement on the server.

The Statement object is put into the top-level of the mysql.stmt subpackage for convenience.

Classes | [hide private]
`` | Statement Parsed SQL statement object.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.7 $'`

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.7 $'